@@ -1,5 +1,6 @@
 require 'cgi'
 require 'net/https'
+require 'net/http/post/multipart'
 
 module Fogbugz
   module Adapter
@@ -9,24 +10,32 @@ module Fogbugz
 
         def initialize(options = {})
           @root_url = options[:uri]
+          @ca_file = options[:ca_file]
+        end
+
+        def build_request(uri, params)
+          return Net::HTTP::Post::Multipart.new(uri.request_uri, params) if params.key? :File1
+
+          request = Net::HTTP::Post.new(uri.request_uri)
+          request.set_form_data(params)
+          request
         end
 
         def request(action, options)
           uri = URI("#{@root_url}/api.asp")
 
-          params = {
-            'cmd' => action
-          }
+          params = { 'cmd' => action }
           params.merge!(options[:params])
 
-          # build up the form request
-          request = Net::HTTP::Post.new(uri.request_uri)
-          request.set_form_data(params)
+          request = build_request(uri, params)
 
           http = Net::HTTP.new(uri.host, uri.port)
-          http.use_ssl = @root_url.start_with? 'https'
-          
-          response = http.start {|http| http.request(request) }
+          if @root_url.start_with? 'https'
+            http.use_ssl = true
+            http.ca_file = @ca_file
+          end
+
+          response = http.start { |h| h.request(request) }
           response.body
         end
       end
